@@ -1000,36 +1000,36 @@ a Z="\t z":
 
 test! {
   name:     line_continuation_with_space,
-  justfile: r#"
+  justfile: r"
 foo:
   echo a\
          b  \
              c
-"#,
+",
   stdout:   "ab c\n",
   stderr:   "echo ab  c\n",
 }
 
 test! {
   name:     line_continuation_with_quoted_space,
-  justfile: r#"
+  justfile: r"
 foo:
   echo 'a\
          b  \
              c'
-"#,
+",
   stdout:   "ab  c\n",
   stderr:   "echo 'ab  c'\n",
 }
 
 test! {
   name:     line_continuation_no_space,
-  justfile: r#"
+  justfile: r"
 foo:
   echo a\
   b\
   c
-"#,
+",
   stdout:   "abc\n",
   stderr:   "echo abc\n",
 }
@@ -1914,6 +1914,66 @@ test! {
   shell: false,
 }
 
+test! {
+  name: env_function_as_env_var,
+  justfile: "
+    foo: (bar env('x'))
+
+    bar arg:
+      echo {{arg}}
+  ",
+  args: (),
+  env: { "x": "z", },
+  stdout: "z\n",
+  stderr: "echo z\n",
+  shell: false,
+}
+
+test! {
+  name: env_function_as_env_var_or_default,
+  justfile: "
+    foo: (bar env('x', 'y'))
+
+    bar arg:
+      echo {{arg}}
+  ",
+  args: (),
+  env: { "x": "z", },
+  stdout: "z\n",
+  stderr: "echo z\n",
+  shell: false,
+}
+
+test! {
+  name: env_function_as_env_var_with_existing_env_var,
+  justfile: "
+    foo: (bar env('x'))
+
+    bar arg:
+      echo {{arg}}
+  ",
+  args: (),
+  env: { "x": "z", },
+  stdout: "z\n",
+  stderr: "echo z\n",
+  shell: false,
+}
+
+test! {
+  name: env_function_as_env_var_or_default_with_existing_env_var,
+  justfile: "
+    foo: (bar env('x', 'y'))
+
+    bar arg:
+      echo {{arg}}
+  ",
+  args: (),
+  env: { "x": "z", },
+  stdout: "z\n",
+  stderr: "echo z\n",
+  shell: false,
+}
+
 test! {
   name: dependency_argument_backtick,
   justfile: "
